/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2022                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  Copyright (c) 2011                                                     **
**  University of Oregon, Eugene, USA                                      **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/





package scalasca.cubex.cube;
import java.lang.String;
/*
 * Class , delivers file structure of CubeX
 *
 */
public class Location extends NamedVertex
{
    protected long         rank = -1;
    protected LocationType type = LocationType.CPU_THREAD;


//     @SuppressWarnings("unchecked")
    public Location()
    {
        super( "Location" );
    }
    public Location( int _id, LocationGroup _parent )
    {
        super( _id, "Location", _parent );
    }
    public Location( int _id, long _rank, LocationType _type, LocationGroup _parent )
    {
        super( _id, "Location", _parent );
        rank = _rank;
        type = _type;
    }
    public Location( int _id, long _rank, String _name, LocationType _type, LocationGroup _parent )
    {
        super( _id, _name, _parent );
        rank = _rank;
        type = _type;
    }

    public void
    init( long _rank, String _name, LocationType _type )
    {
        setName( _name );
        rank = _rank;
        type = _type;
    }

    public long
    getRank()
    {
        return rank;
    }


    public String
    getName()
    {
        return super.getName() + " " + String.valueOf( rank );
    }

    public LocationType
    getType()
    {
        return type;
    }
    public String
    getTypeAsString()
    {
        if ( type == LocationType.CPU_THREAD )
        {
            return "thread";
        }
        if ( type == LocationType.ACCELERATOR_STREAM )
        {
            return "accelerator stream";
        }
        if ( type == LocationType.METRIC )
        {
            return "metric";
        }
        return "not supported";
    }



    public static LocationType
    getLocationType( String _type ) throws scalasca.cubex.cube.errors.BadSyntaxException
    {
        if ( _type.equals( "thread" ) )
        {
            return LocationType.CPU_THREAD;
        }
        if ( _type.equals( "gpu" ) || _type.equals( "accelerator stream" ) )
        {
            return LocationType.ACCELERATOR_STREAM;
        }
        if ( _type.equals( "metric" ) )
        {
            return LocationType.METRIC;
        }
        throw new scalasca.cubex.cube.errors.BadSyntaxException( "Do not support location type " + _type );
    }
}
