/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2022                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  Copyright (c) 2011                                                     **
**  University of Oregon, Eugene, USA                                      **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/





package scalasca.cubex.cube;
import java.lang.String;
/*
 * Class , delivers file structure of CubeX
 *
 */
public class LocationGroup extends NamedVertex
{
    protected long    rank = -1;
    LocationGroupType type =  LocationGroupType.PROCESS;

//     @SuppressWarnings("unchecked")
    public LocationGroup()
    {
        super( "Process" );
    }
    public LocationGroup( int _id, SystemTreeNode _parent )
    {
        super( _id, "Process", null );
        parent = _parent;
        ( ( SystemTreeNode )parent ).addLocationGroup( this );
    }
    public LocationGroup( int _id, long _rank, LocationGroupType _type, SystemTreeNode _parent )
    {
        super( _id, "Process", null );
        parent = _parent;
        type   = _type;
        ( ( SystemTreeNode )parent ).addLocationGroup( this );
        rank = _rank;
    }
    public LocationGroup( int _id, long _rank, String _name, LocationGroupType _type, SystemTreeNode _parent )
    {
        super( _id, _name, null );
        parent = _parent;
        type   = _type;
        ( ( SystemTreeNode )parent ).addLocationGroup( this );
        rank = _rank;
    }

    public void
    init( long _rank, String _name, LocationGroupType _type )
    {
        setName( _name );
        rank = _rank;
        type = _type;
    }

    public long
    getRank()
    {
        return rank;
    }


    public String
    getName()
    {
        return super.getName() + " " + String.valueOf( rank );
    }

    public LocationGroupType
    getType()
    {
        return type;
    }
    public String
    getTypeAsString()
    {
        if ( type == LocationGroupType.PROCESS )
        {
            return "process";
        }
        if ( type == LocationGroupType.METRICS )
        {
            return "metrics";
        }
        if ( type == LocationGroupType.ACCELERATOR )
        {
            return "accelerator";
        }
        return "not supported";
    }


    public static
    LocationGroupType
    getLocationGroupType( String _type ) throws scalasca.cubex.cube.errors.BadSyntaxException
    {
        if ( _type.equals( "process" ) )
        {
            return LocationGroupType.PROCESS;
        }
        if ( _type.equals( "metrics" ) )
        {
            return LocationGroupType.METRICS;
        }
        if ( _type.equals( "accelerator" ) )
        {
            return LocationGroupType.ACCELERATOR;
        }
        throw new scalasca.cubex.cube.errors.BadSyntaxException( "Do not support location group type " + _type );
    }
}
