/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  Copyright (c) 2011                                                     **
**  University of Oregon, Eugene, USA                                      **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


package scalasca.cubex.cube.datalayout.data.value;
import scalasca.cubex.cube.errors.*;
import scalasca.cubex.cube.services.transformation.*;

import java.lang.*;
import java.util.*;
import java.io.*;
import java.lang.Math;
/*
 * Class , delivers file structure of CubeX
 *
 */
public class CubeHistogram extends Value
{
    protected int                N;
    protected CubeDouble         _service_exemplar = new  CubeDouble();
    protected Vector<CubeDouble> values            = new Vector<CubeDouble>();

    public CubeHistogram()
    {
        N = 0;
        values.clear();
    };


    public CubeHistogram( int _n )
    {
        N = _n;
        values.clear();
        for ( int i = 0; i < N; i++ )
        {
            values.add( new CubeDouble() );
        }
    };

    public CubeHistogram( Vector<CubeDouble> _values )
    {
        N      = _values.size();
        values = _values;
    };


    public String
    getName()
    {
        return "HISTOGRAM";
    }
    public String
    toString()
    {
        String toReturn = "(";
        for ( CubeDouble _v : values )
        {
            toReturn += String.valueOf( _v.getDouble() ) + " ";
        }
        toReturn += ")";
        return toReturn;
    }

    public int
    size()
    {
        return ( int )( N * _service_exemplar.size() );
    };

    public void
    correctEndianess( Endianess _end, DataInputStream in, DataOutputStream out )  throws IOException
    {
        for ( CubeDouble _v : values )
        {
            _v.correctEndianess( _end, in, out );
            ;
        }
    }

    public Value
    clone()
    {
        return new CubeHistogram( N );
    }
    public Value
    copy()
    {
        Vector<CubeDouble> _values = new Vector<CubeDouble>();
        for ( CubeDouble _v : values )
        {
            _values.add( new CubeDouble( _v.getDouble() ) );
        }
        return new CubeHistogram( _values );
    }

    public Value
    clone( DataInputStream in )  throws IOException
    {
        Vector<CubeDouble> _values = new Vector<CubeDouble>();
        for ( CubeDouble _v : values )
        {
            double __d = in.readDouble();
            _values.add( new CubeDouble( __d ) );
        }
        return new CubeHistogram( _values );
    }


    // ------------------- setXXX methods ------------------
    public void
    setValue( String str )                // initialization from String
    {
//              value = 0; // here is parsing needed
    }
    public void
    setValue( byte v )                // initialization from byte
    {
//              value = 0;
    }

    public void
    setValue( short v )                // initialization from short
    {
//              value = Short(value).byteValue();
    }
    public void
    setValue( int v )                // initialization from integer
    {
//              value = Integer(value).byteValue();
    }
    public void
    setValue( long v )                // initialization from long
    {
//              value = Long(value).byteValue();
    }
    public void
    setValue( double v )                // initialization from double
    {
//              value = Double(value).byteValue();
    }


    // ------------------- getXXX methods ------------------
    public double
    getDouble()
    {
        double toReturn = 0;
        for ( CubeDouble _v : values )
        {
            toReturn += _v.getDouble();
        }
        return toReturn;
    }

    public double
    getN()
    {
        return N;
    }



    // -------------------- lagebra -------------------------
    public void
    addValue( Value v )                // performs operation "+"
    {
        CubeHistogram _v = ( CubeHistogram )v;
    }

    public void
    subtractValue( Value v )                // performs operation "-", if defined
    {
        CubeHistogram _v = ( CubeHistogram )v;
    }

    public void
    setValueParameters( Vector<Double> parameters ) throws WrongNumberOfValueParametersException
    {
        if ( parameters.size() < 1 )
        {
            throw new WrongNumberOfValueParametersException( parameters.size(), 1, "HISTOGRAM" );
        }
        N = ( parameters.get( 0 ) ).intValue();
        values.clear();
        for ( int i = 0; i < N; i++ )
        {
            values.add( new CubeDouble() );
        }
    };
}
