/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2019                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  Copyright (c) 2011                                                     **
**  University of Oregon, Eugene, USA                                      **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/



/**
 * Collection of classes, which describes layout of cube report and delivers a raw data for parsing.
 */
package scalasca.cubex.cubexlayout;
import scalasca.cubex.tarviewer.*;
import java.io.FileInputStream;
import java.lang.*;
import java.util.*;
import java.io.*;
import scalasca.cubex.cube.errors.*;


/**
 * Provides for a cube parser information about the place where to look for an anchor and metric data files.
 * Besides of that  reads content of that file and returns as an array byte[]. Cube uses that array and does not read in file
 */
public class CubeLayout// cube3 test and layout
{
    protected String filename;

    protected long AnchorShift = -1;
    protected long AnchorSize  = -1;

    protected Map<Long, Map< String, Long> >   metricDataPlaces       = new HashMap<Long, Map <String, Long> >();    // id.data : id ->  (offset, size)
    protected Map<Long, Map< String, Long> >   metricIndexPlaces      = new HashMap<Long, Map <String, Long> > ();   // id.index : id -> (offset, size)
    protected Map<Long, Map< String, Long> >   ghostMetricDataPlaces  = new HashMap<Long, Map <String, Long> >();    // id.data : id ->  (offset, size)
    protected Map<Long, Map< String, Long> >   ghostMetricIndexPlaces = new HashMap<Long, Map <String, Long> > ();   // id.index : id -> (offset, size)
    protected Map<String, Map< String, Long> > miscDataPlaces         = new HashMap<String, Map <String, Long> > (); // dataname : name -> (offset, size)



    @SuppressWarnings( "unchecked" )
    public CubeLayout( String _filename )
    {
        filename = _filename;
        File _f = new File( filename );
        AnchorSize  = _f.length();
        AnchorShift = 0;
    }



    public long
    getAnchorSize()
    {
        return AnchorSize;
    }

    public long
    getAnchorShift()
    {
        return AnchorShift;
    }



    public long
    getMetricDataSize( int id ) throws MissingMetricInCubeReport
    {
        return 0;
    }

    public long
    getMetricDataShift( int id ) throws MissingMetricInCubeReport
    {
        return 0;
    }

    public long
    getMetricIndexSize( int id ) throws MissingMetricInCubeReport
    {
        return 0;
    }

    public long
    getMetricIndexShift( int id ) throws MissingMetricInCubeReport
    {
        return 0;
    }

    public long
    getMiscDataSize( String name ) throws MissingMiscInCubeReport
    {
        return 0;
    }

    public long
    getMiscDataShift( String name ) throws MissingMiscInCubeReport
    {
        return 0;
    }



    public void
    print()
    {
        System.out.println( " ====== Simply Cube 3 layout ========" );
        System.out.println( "Anchor size:      " + AnchorSize );
        System.out.println( "Anchor offset:   " + AnchorShift );
    }


    static public CubeLayout
    getCubeLayout( String _filename )
    {
        if ( CubeTarLayout.testLayout( _filename ) )
        {
            return new CubeTarLayout( _filename );
        }
        if ( Cube3GZIPLayout.testLayout( _filename ) )
        {
            return new Cube3GZIPLayout( _filename );
        }

        return new CubeLayout( _filename );
    }



    static boolean
    testLayout( String _filename )
    {
        return true;
    }


    public byte[]
    getAnchorBytes() throws IOException
    {
        try{
            FileInputStream fis = new FileInputStream( filename );
            fis.skip( AnchorShift );

            byte anchor[] = new byte[ ( int )AnchorSize ];

            fis.read( anchor );
            fis.close();
            return anchor;
        }
        catch ( FileNotFoundException e )
        {
            System.out.println( "File " + filename + " not found." );
            return new byte[ 0 ];
        }
    }


    public byte[]
    getMetricDataBytes( int id ) throws IOException, MissingMetricInCubeReport
    {
        return new byte[ 0 ];
    }

    public byte[]
    getMetricIndexBytes( int id ) throws IOException, MissingMetricInCubeReport
    {
        return new byte[ 0 ];
    }

    public byte[]
    getMiscDataBytes( String name ) throws IOException, MissingMiscInCubeReport
    {
        return new byte[ 0 ];
    }
}
