/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


package scalasca.cubex.tarviewer;
/**

   Provides a short description of  files in the tar file : size, offset and a name.
   Used by Cube to get a direct access to the tar content.
 */
public class BTarEntry
{
    private long    offset;
    private String  name;
    private long    size;
    private boolean isDirectory;

    public BTarEntry( String name, long size, long offset, boolean isDirectory )
    {
        this.offset      = offset;
        this.name        = name;
        this.size        = size;
        this.isDirectory = isDirectory;
    }

    /**
     * Returns the name of the file
       @return      string representing the name of the file/folder
     *
     */
    public String
    getName()
    {
        return name;
    }

    /**
     * Returns the offset of the file inside the TAR archive
            @return      Offset of the file inside the TAR archive easured in bytes
     */
    public long
    getOffset()
    {
        return offset;
    }

    /**
     * Returns the size of the file inside the TAR archive
            @return      Size of the file measured in bytes
     */
    public long
    getSize()
    {
        return size;
    }

    /**
     * Returns true if directory is returned, false otherwise
     */
    public boolean
    isDirectory()
    {
        return isDirectory;
    }

    @Override
    /**
     * Returns a colon-separated list [name:offset(bytes):size(bytes)] string that represents the object
       @return      string representing the object
     *
     */
    public String
    toString()
    {
        return name + ":" + offset + ":" + size + ":" + isDirectory;
    }
}
