/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


package scalasca.cubex.tarviewer;
import java.io.File;
import java.util.Date;

public class PaxEntry
{
    protected File file;
    protected Long size;
    private PaxEntry()
    {
        this.file = null;
    }


    public PaxEntry( byte[] headerBuf )
    {
        this( );
        this.parsePaxHeader( headerBuf );
    }

    public long
    getSize()
    {
        return this.size;
    }

    /**
     * Parses the tar header to the byte buffer
     *
     * @param header
     * @param bh
     */
    public void
    parsePaxHeader( byte[] bh )
    {
        int     offset = 0;
        PaxPair pair   = new PaxPair();
        while ( !pair.keyword.equals( "size" ) || offset >= bh.length )
        {
            offset = parseChunk( bh, offset, pair );
        }
        if ( pair.keyword.equals( "size" ) )
        {
            size = Long.valueOf( pair.value.trim() );
        }
    }

    public int
    parseChunk( byte[] bh, int offset, PaxPair pair )
    {
        byte[] len = new byte[ bh.length ];
        int    i   = 0;
        while ( bh[ offset + i ] != ' ' )
        {
            len[ i ] = ( byte )bh[ offset + i ];
            i++;
        }
        offset += i + 1;
        int    local_len = Integer.parseInt( new String( len ).trim() );
        byte[] _paxentry = new byte[ bh.length ];
        for ( i = 0; i < local_len - offset - 1; ++i )
        {
            _paxentry[ i ] = ( byte )bh[ offset + i ];
        }
        offset += i;
        String[] paxentry = ( new String( _paxentry ) ).split( "[\\s=\n]", 0 );
        pair.keyword = paxentry[ 0 ];
        pair.value   = paxentry[ 1 ];
        return offset;
    }
}
